.. _get_involved:

Get Involved
============

.. toctree::
   :maxdepth: 1
   :hidden:

   get_involved/contributing
   get_involved/mentoring
   get_involved/meetups
   get_involved/code_of_conduct
   get_involved/governance

aeon is a community-driven project and your help is extremely welcome.
If you get stuck, please don’t hesitate to chat with us or raise an issue.

.. grid:: 1 2 2 2
    :gutter: 3

    .. grid-item-card::
        :text-align: center

        Contributing

        ^^^

        New to aeon? Check out the contributing guide.

        +++

        .. button-ref:: contributing
            :color: primary
            :click-parent:
            :expand:

            Contributing guide

    .. grid-item-card::
        :text-align: center

        Mentoring

        ^^^

        New to open source? Apply to our mentoring program!

        +++

        .. button-ref:: mentoring
            :color: primary
            :click-parent:
            :expand:

            Mentoring

    .. grid-item-card::
        :text-align: center

        Sponsoring

        ^^^

        Fund aeon maintenance and development.

        +++

        .. button-link:: https://opencollective.com/aeon
            :color: primary
            :click-parent:
            :expand:

            Donate

    .. grid-item-card::
        :text-align: center

        Meet-ups

        ^^^

        Join our discussions, tutorials, workshops and sprints!

        +++

        .. button-ref:: meetups
            :color: primary
            :click-parent:
            :expand:

            Participate

    .. grid-item-card::
        :text-align: center

        Code of Conduct

        ^^^



        +++

        .. button-ref:: code_of_conduct
            :color: primary
            :click-parent:
            :expand:

            Code of Conduct

    .. grid-item-card::
        :text-align: center

        Governance

        ^^^



        +++

        .. button-ref:: governance
            :color: primary
            :click-parent:
            :expand:

            Governance
